/****************************************************************************
** Meta object code from reading C++ file 'UIVirtualBoxEventHandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/VBox/Frontends/VirtualBox/src/globals/UIVirtualBoxEventHandler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UIVirtualBoxEventHandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24UIVirtualBoxEventHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto UIVirtualBoxEventHandler::qt_create_metaobjectdata<qt_meta_tag_ZN24UIVirtualBoxEventHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UIVirtualBoxEventHandler",
        "sigMachineStateChange",
        "",
        "QUuid",
        "uId",
        "KMachineState",
        "state",
        "sigMachineDataChange",
        "sigMachineRegistered",
        "fRegistered",
        "sigMachineGroupsChange",
        "sigSessionStateChange",
        "KSessionState",
        "sigSnapshotTake",
        "uSnapshotId",
        "sigSnapshotDelete",
        "sigSnapshotChange",
        "sigSnapshotRestore",
        "sigCloudProviderUninstall",
        "sigCloudProviderListChanged",
        "sigCloudProfileRegistered",
        "uProviderId",
        "strName",
        "sigCloudProfileChanged",
        "sigStorageControllerChange",
        "uMachineId",
        "strControllerName",
        "sigStorageDeviceChange",
        "CMediumAttachment",
        "comAttachment",
        "fRemoved",
        "fSilent",
        "sigMediumChange",
        "sigMediumConfigChange",
        "CMedium",
        "comMedium",
        "sigMediumRegistered",
        "uMediumId",
        "KDeviceType",
        "enmMediumType",
        "sigExtensionPackInstalled",
        "sigExtensionPackUninstalled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigMachineStateChange'
        QtMocHelpers::SignalData<void(const QUuid &, const KMachineState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'sigMachineDataChange'
        QtMocHelpers::SignalData<void(const QUuid &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigMachineRegistered'
        QtMocHelpers::SignalData<void(const QUuid &, const bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'sigMachineGroupsChange'
        QtMocHelpers::SignalData<void(const QUuid &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigSessionStateChange'
        QtMocHelpers::SignalData<void(const QUuid &, const KSessionState)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 12, 6 },
        }}),
        // Signal 'sigSnapshotTake'
        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 14 },
        }}),
        // Signal 'sigSnapshotDelete'
        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 14 },
        }}),
        // Signal 'sigSnapshotChange'
        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 14 },
        }}),
        // Signal 'sigSnapshotRestore'
        QtMocHelpers::SignalData<void(const QUuid &, const QUuid &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 14 },
        }}),
        // Signal 'sigCloudProviderUninstall'
        QtMocHelpers::SignalData<void(const QUuid &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigCloudProviderListChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigCloudProfileRegistered'
        QtMocHelpers::SignalData<void(const QUuid &, const QString &, bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 21 }, { QMetaType::QString, 22 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'sigCloudProfileChanged'
        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 21 }, { QMetaType::QString, 22 },
        }}),
        // Signal 'sigStorageControllerChange'
        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 25 }, { QMetaType::QString, 26 },
        }}),
        // Signal 'sigStorageDeviceChange'
        QtMocHelpers::SignalData<void(CMediumAttachment, bool, bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 }, { QMetaType::Bool, 30 }, { QMetaType::Bool, 31 },
        }}),
        // Signal 'sigMediumChange'
        QtMocHelpers::SignalData<void(CMediumAttachment)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Signal 'sigMediumConfigChange'
        QtMocHelpers::SignalData<void(CMedium)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'sigMediumRegistered'
        QtMocHelpers::SignalData<void(const QUuid &, KDeviceType, bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 37 }, { 0x80000000 | 38, 39 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'sigExtensionPackInstalled'
        QtMocHelpers::SignalData<void(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Signal 'sigExtensionPackUninstalled'
        QtMocHelpers::SignalData<void(const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UIVirtualBoxEventHandler, qt_meta_tag_ZN24UIVirtualBoxEventHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UIVirtualBoxEventHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24UIVirtualBoxEventHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24UIVirtualBoxEventHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24UIVirtualBoxEventHandlerE_t>.metaTypes,
    nullptr
} };

void UIVirtualBoxEventHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UIVirtualBoxEventHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigMachineStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[2]))); break;
        case 1: _t->sigMachineDataChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 2: _t->sigMachineRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->sigMachineGroupsChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 4: _t->sigSessionStateChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KSessionState>>(_a[2]))); break;
        case 5: _t->sigSnapshotTake((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 6: _t->sigSnapshotDelete((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 7: _t->sigSnapshotChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 8: _t->sigSnapshotRestore((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 9: _t->sigCloudProviderUninstall((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 10: _t->sigCloudProviderListChanged(); break;
        case 11: _t->sigCloudProfileRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 12: _t->sigCloudProfileChanged((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->sigStorageControllerChange((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->sigStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 15: _t->sigMediumChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
        case 16: _t->sigMediumConfigChange((*reinterpret_cast<std::add_pointer_t<CMedium>>(_a[1]))); break;
        case 17: _t->sigMediumRegistered((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDeviceType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 18: _t->sigExtensionPackInstalled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->sigExtensionPackUninstalled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KMachineState >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KSessionState >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CMediumAttachment >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CMediumAttachment >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CMedium >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDeviceType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , const KMachineState )>(_a, &UIVirtualBoxEventHandler::sigMachineStateChange, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & )>(_a, &UIVirtualBoxEventHandler::sigMachineDataChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , const bool )>(_a, &UIVirtualBoxEventHandler::sigMachineRegistered, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & )>(_a, &UIVirtualBoxEventHandler::sigMachineGroupsChange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , const KSessionState )>(_a, &UIVirtualBoxEventHandler::sigSessionStateChange, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , const QUuid & )>(_a, &UIVirtualBoxEventHandler::sigSnapshotTake, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , const QUuid & )>(_a, &UIVirtualBoxEventHandler::sigSnapshotDelete, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , const QUuid & )>(_a, &UIVirtualBoxEventHandler::sigSnapshotChange, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , const QUuid & )>(_a, &UIVirtualBoxEventHandler::sigSnapshotRestore, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & )>(_a, &UIVirtualBoxEventHandler::sigCloudProviderUninstall, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)()>(_a, &UIVirtualBoxEventHandler::sigCloudProviderListChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , const QString & , bool )>(_a, &UIVirtualBoxEventHandler::sigCloudProfileRegistered, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , const QString & )>(_a, &UIVirtualBoxEventHandler::sigCloudProfileChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , const QString & )>(_a, &UIVirtualBoxEventHandler::sigStorageControllerChange, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(CMediumAttachment , bool , bool )>(_a, &UIVirtualBoxEventHandler::sigStorageDeviceChange, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(CMediumAttachment )>(_a, &UIVirtualBoxEventHandler::sigMediumChange, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(CMedium )>(_a, &UIVirtualBoxEventHandler::sigMediumConfigChange, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QUuid & , KDeviceType , bool )>(_a, &UIVirtualBoxEventHandler::sigMediumRegistered, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QString & )>(_a, &UIVirtualBoxEventHandler::sigExtensionPackInstalled, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (UIVirtualBoxEventHandler::*)(const QString & )>(_a, &UIVirtualBoxEventHandler::sigExtensionPackUninstalled, 19))
            return;
    }
}

const QMetaObject *UIVirtualBoxEventHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UIVirtualBoxEventHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24UIVirtualBoxEventHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UIVirtualBoxEventHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void UIVirtualBoxEventHandler::sigMachineStateChange(const QUuid & _t1, const KMachineState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void UIVirtualBoxEventHandler::sigMachineDataChange(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void UIVirtualBoxEventHandler::sigMachineRegistered(const QUuid & _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void UIVirtualBoxEventHandler::sigMachineGroupsChange(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UIVirtualBoxEventHandler::sigSessionStateChange(const QUuid & _t1, const KSessionState _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void UIVirtualBoxEventHandler::sigSnapshotTake(const QUuid & _t1, const QUuid & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void UIVirtualBoxEventHandler::sigSnapshotDelete(const QUuid & _t1, const QUuid & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void UIVirtualBoxEventHandler::sigSnapshotChange(const QUuid & _t1, const QUuid & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void UIVirtualBoxEventHandler::sigSnapshotRestore(const QUuid & _t1, const QUuid & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void UIVirtualBoxEventHandler::sigCloudProviderUninstall(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void UIVirtualBoxEventHandler::sigCloudProviderListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void UIVirtualBoxEventHandler::sigCloudProfileRegistered(const QUuid & _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3);
}

// SIGNAL 12
void UIVirtualBoxEventHandler::sigCloudProfileChanged(const QUuid & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void UIVirtualBoxEventHandler::sigStorageControllerChange(const QUuid & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void UIVirtualBoxEventHandler::sigStorageDeviceChange(CMediumAttachment _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void UIVirtualBoxEventHandler::sigMediumChange(CMediumAttachment _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void UIVirtualBoxEventHandler::sigMediumConfigChange(CMedium _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void UIVirtualBoxEventHandler::sigMediumRegistered(const QUuid & _t1, KDeviceType _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}

// SIGNAL 18
void UIVirtualBoxEventHandler::sigExtensionPackInstalled(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void UIVirtualBoxEventHandler::sigExtensionPackUninstalled(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}
QT_WARNING_POP
